% gradel_project

close all;

FILTER = 'db4';

% -------------------------------------------------------------------------
% Illustrate the forward and reverse wavelet transform, and what the
% coefficient matrix looks like -- a small subsampled image, and a set
% of coefficients that allow it to be reconstructed
% -------------------------------------------------------------------------

% Read sample image convert to grayscale and display
I = imread('turkey.jpg');
f = rgb2gray(I);
figure; imshow(f); title 'Original';

% Forward waveley transform to [c,s]
[c, s] = wavefast(f, 2, FILTER);

% Display standard, 8x and absolute 8x
figure; wave2gray(c, s); title 'Show Coefficients';
figure; wave2gray(c, s, 8); title 'Magnify by 8';
figure; wave2gray(c, s, -8); title 'Magnify by abs(8)'

% Compute the inverse tranform
g = waveback(c, s, FILTER);
I = uint8(g);
figure; imshow(I); title 'Reverse';

disp 'Press ENTER to continue.'
pause;
close all;

% -------------------------------------------------------------------------
% Illustrate what would happen if you eliminated one of the layers (for
% compression purposes presumably)
% -------------------------------------------------------------------------

% Read sample image convert to grayscale and display
I = imread('turkey.jpg');
f = rgb2gray(I);
figure; imshow(f); title 'Original';

% Forward wavelet transform to [c,s] but use 4 levels
FILTER = 'sym4';
[c, s] = wavefast(f, 4, FILTER);

% Zero each layer of wavelet coefficients and show results.
[c, g8] = wavezero(c, s, 1, FILTER); title 'Zero 1';
% figure; imshow(g8); title 'Zero 1';
[c, g8] = wavezero(c, s, 2, FILTER); title 'Zero 2';
% figure; imshow(g8); title 'Zero 2';
[c, g8] = wavezero(c, s, 3, FILTER); title 'Zero 3';
% figure; imshow(g8); title 'Zero 3';
[c, g8] = wavezero(c, s, 4, FILTER); title 'Zero 4';
% figure; imshow(g8); title 'Zero 4';

disp 'Press ENTER to continue.'
pause;
close all; 

% -------------------------------------------------------------------------
% Illustrate reconstructing successively larger and images, with more
% detail from a coefficient matrix.
% -------------------------------------------------------------------------

% Read sample image convert to grayscale and display
I = imread('turkey.jpg');
f = rgb2gray(I);
figure; imshow(f); title 'Original';

% Forward wavelet transform to [c,s] but use 4 levels
FILTER = 'jpeg9.7';
[c, s] = wavefast(f, 4, FILTER);
wave2gray(c, s, 8);

f = wavecopy('a', c, s);
figure; imshow(mat2gray(f)); title 'Approximation 1';

[c, s] = waveback(c, s, FILTER, 1);
f = wavecopy('a', c, s);
figure; imshow(mat2gray(f)); title 'Approximation 2';

[c, s] = waveback(c, s, FILTER, 1);
f = wavecopy('a', c, s);
figure; imshow(mat2gray(f)); title 'Approximation 3';

[c, s] = waveback(c, s, FILTER, 1);
f = wavecopy('a', c, s);
figure; imshow(mat2gray(f)); title 'Approximation 4';






